import { useSigma } from "react-sigma-v2";
import { FC, useEffect } from "react";

const GraphData: FC = ({ children }) => {
  const sigma = useSigma();
  const graph = sigma.getGraph();

  // Load data on mount:
  useEffect(() => {
    fetch("./dataset.json")
      .then((res) => res.json())
      .then(
        (dataset: {
          nodes: {
            key: string;
            label: string;
            tag: string;
            URL: string;
            cluster: string;
            x: number;
            y: number;
          }[];
          edges: [string, string][];
          clusters: Record<string, { color: string; label: string }>;
          tags: Record<string, { image: string }>;
        }) => {
          graph.clear();

          dataset.nodes.forEach((node) =>
            graph.addNode(node.key, { ...node, ...dataset.clusters[node.cluster], ...dataset.tags[node.tag] }),
          );
          dataset.edges.forEach(([source, target]) => graph.addEdge(source, target, {size: 2}));

          // Use degrees as node sizes:
          const degrees = graph.nodes().map((node) => graph.degree(node));
          const minDegree = Math.min(...degrees);
          const maxDegree = Math.max(...degrees);
          const MIN_NODE_SIZE = 3;
          const MAX_NODE_SIZE = 30;
          graph.forEachNode((node) =>
            graph.setNodeAttribute(
              node,
              "size",
              ((graph.degree(node) - minDegree) / (maxDegree - minDegree)) * (MAX_NODE_SIZE - MIN_NODE_SIZE) +
                MIN_NODE_SIZE,
            ),
          );
        },
      );
  }, []);

  return <>{children}</>;
};

export default GraphData;
